==> prestashop_edition_basic_version_8.2.0.zip: modules/ps_mbo/src/Module/Exception/TransitionFailedException.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace PrestaShop\Module\Mbo\Module\Exception;

class TransitionFailedException extends \Exception
{
    /**
     * @var array
     */
    private $context;

    public function __construct(string $transitionName, array $context = [], \Throwable $previous = null)
    {
        parent::__construct(
            sprintf('Module action failed without any further details. Transition "%s"', $transitionName),
            0,
            $previous
        );

        $context['previous_exception_class'] = $previous ? get_class($previous) : null;
        $context['previous_exception_message'] = $previous ? $previous->getMessage() : null;

        $this->context = $context;
    }

    public function getContext(): array
    {
        return $this->context;
    }
}

==> prestashop_edition_basic_version_9.0.1-1.0.zip: modules/ps_mbo/src/Module/Exception/TransitionFailedException.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace PrestaShop\Module\Mbo\Module\Exception;

class TransitionFailedException extends \Exception
{
    /**
     * @var array
     */
    private $context;

    public function __construct(string $transitionName, array $context = [], ?\Throwable $previous = null)
    {
        parent::__construct(
            sprintf('Module action failed without any further details. Transition "%s"', $transitionName),
            0,
            $previous
        );

        $context['previous_exception_class'] = $previous ? get_class($previous) : null;
        $context['previous_exception_message'] = $previous ? $previous->getMessage() : null;

        $this->context = $context;
    }

    public function getContext(): array
    {
        return $this->context;
    }
}
